@@ -44,89 +44,95 @@ abuilder = builder.AstroidBuilder()
 BUILTINS = six.moves.builtins.__name__
 try:
     import typed_ast  # pylint: disable=unused-import
+
     HAS_TYPED_AST = True
 except ImportError:
     HAS_TYPED_AST = False
 
 
 class AsStringTest(resources.SysPathSetup, unittest.TestCase):
-
     def test_tuple_as_string(self):
         def build(string):
             return abuilder.string_build(string).body[0].value
 
-        self.assertEqual(build('1,').as_string(), '(1, )')
-        self.assertEqual(build('1, 2, 3').as_string(), '(1, 2, 3)')
-        self.assertEqual(build('(1, )').as_string(), '(1, )')
-        self.assertEqual(build('1, 2, 3').as_string(), '(1, 2, 3)')
+        self.assertEqual(build("1,").as_string(), "(1, )")
+        self.assertEqual(build("1, 2, 3").as_string(), "(1, 2, 3)")
+        self.assertEqual(build("(1, )").as_string(), "(1, )")
+        self.assertEqual(build("1, 2, 3").as_string(), "(1, 2, 3)")
 
-    @test_utils.require_version(minver='3.0')
+    @test_utils.require_version(minver="3.0")
     def test_func_signature_issue_185(self):
-        code = textwrap.dedent('''
+        code = textwrap.dedent(
+            """
         def test(a, b, c=42, *, x=42, **kwargs):
             print(a, b, c, args)
-        ''')
+        """
+        )
         node = parse(code)
         self.assertEqual(node.as_string().strip(), code.strip())
 
     def test_as_string_for_list_containing_uninferable(self):
-        node = builder.extract_node('''
+        node = builder.extract_node(
+            """
         def foo():
             bar = [arg] * 1
-        ''')
+        """
+        )
         binop = node.body[0].value
         inferred = next(binop.infer())
-        self.assertEqual(inferred.as_string(), '[Uninferable]')
-        self.assertEqual(binop.as_string(), '[arg] * 1')
+        self.assertEqual(inferred.as_string(), "[Uninferable]")
+        self.assertEqual(binop.as_string(), "[arg] * 1")
 
     def test_frozenset_as_string(self):
-        ast_nodes = builder.extract_node('''
+        ast_nodes = builder.extract_node(
+            """
         frozenset((1, 2, 3)) #@
         frozenset({1, 2, 3}) #@
         frozenset([1, 2, 3,]) #@
 
         frozenset(None) #@
         frozenset(1) #@
-        ''')
+        """
+        )
         ast_nodes = [next(node.infer()) for node in ast_nodes]
 
-        self.assertEqual(ast_nodes[0].as_string(), 'frozenset((1, 2, 3))')
-        self.assertEqual(ast_nodes[1].as_string(), 'frozenset({1, 2, 3})')
-        self.assertEqual(ast_nodes[2].as_string(), 'frozenset([1, 2, 3])')
+        self.assertEqual(ast_nodes[0].as_string(), "frozenset((1, 2, 3))")
+        self.assertEqual(ast_nodes[1].as_string(), "frozenset({1, 2, 3})")
+        self.assertEqual(ast_nodes[2].as_string(), "frozenset([1, 2, 3])")
 
-        self.assertNotEqual(ast_nodes[3].as_string(), 'frozenset(None)')
-        self.assertNotEqual(ast_nodes[4].as_string(), 'frozenset(1)')
+        self.assertNotEqual(ast_nodes[3].as_string(), "frozenset(None)")
+        self.assertNotEqual(ast_nodes[4].as_string(), "frozenset(1)")
 
     def test_varargs_kwargs_as_string(self):
-        ast = abuilder.string_build('raise_string(*args, **kwargs)').body[0]
-        self.assertEqual(ast.as_string(), 'raise_string(*args, **kwargs)')
+        ast = abuilder.string_build("raise_string(*args, **kwargs)").body[0]
+        self.assertEqual(ast.as_string(), "raise_string(*args, **kwargs)")
 
     def test_module_as_string(self):
         """check as_string on a whole module prepared to be returned identically
         """
-        module = resources.build_file('data/module.py', 'data.module')
-        with open(resources.find('data/module.py'), 'r') as fobj:
+        module = resources.build_file("data/module.py", "data.module")
+        with open(resources.find("data/module.py"), "r") as fobj:
             self.assertMultiLineEqual(module.as_string(), fobj.read())
 
     def test_module2_as_string(self):
         """check as_string on a whole module prepared to be returned identically
         """
-        module2 = resources.build_file('data/module2.py', 'data.module2')
-        with open(resources.find('data/module2.py'), 'r') as fobj:
+        module2 = resources.build_file("data/module2.py", "data.module2")
+        with open(resources.find("data/module2.py"), "r") as fobj:
             self.assertMultiLineEqual(module2.as_string(), fobj.read())
 
     def test_as_string(self):
         """check as_string for python syntax >= 2.7"""
-        code = '''one_two = {1, 2}
+        code = """one_two = {1, 2}
 b = {v: k for (k, v) in enumerate('string')}
-cdd = {k for k in b}\n\n'''
+cdd = {k for k in b}\n\n"""
         ast = abuilder.string_build(code)
         self.assertMultiLineEqual(ast.as_string(), code)
 
-    @test_utils.require_version('3.0')
+    @test_utils.require_version("3.0")
     def test_3k_as_string(self):
         """check as_string for python 3k syntax"""
-        code = '''print()
+        code = """print()
 
 def function(var):
     nonlocal counter
@@ -135,31 +141,41 @@ def function(var):
     except NameError as nexc:
         (*hell, o) = b'hello'
         raise AttributeError from nexc
-\n'''
+\n"""
         ast = abuilder.string_build(code)
         self.assertEqual(ast.as_string(), code)
 
-    @test_utils.require_version('3.0')
+    @test_utils.require_version("3.0")
     @unittest.expectedFailure
     def test_3k_annotations_and_metaclass(self):
-        code_annotations = textwrap.dedent('''
+        code_annotations = textwrap.dedent(
+            '''
         def function(var:int):
             nonlocal counter
 
         class Language(metaclass=Natural):
             """natural language"""
-        ''')
+        '''
+        )
 
         ast = abuilder.string_build(code_annotations)
         self.assertEqual(ast.as_string(), code_annotations)
 
     def test_ellipsis(self):
-        ast = abuilder.string_build('a[...]').body[0]
-        self.assertEqual(ast.as_string(), 'a[...]')
+        ast = abuilder.string_build("a[...]").body[0]
+        self.assertEqual(ast.as_string(), "a[...]")
 
     def test_slices(self):
-        for code in ('a[0]', 'a[1:3]', 'a[:-1:step]', 'a[:,newaxis]',
-                     'a[newaxis,:]', 'del L[::2]', 'del A[1]', 'del Br[:]'):
+        for code in (
+            "a[0]",
+            "a[1:3]",
+            "a[:-1:step]",
+            "a[:, newaxis]",
+            "a[newaxis, :]",
+            "del L[::2]",
+            "del A[1]",
+            "del Br[:]",
+        ):
             ast = abuilder.string_build(code).body[0]
             self.assertEqual(ast.as_string(), code)
 
@@ -170,7 +186,7 @@ del bree[3:d]
 bord[2:]
 del av[d::f], a[df:]
 a[:1] = bord[2:]
-del SRC[::1,newaxis,1:]
+del SRC[::1, newaxis, 1:]
 tous[vals] = 1010
 del thousand[key]
 del a[::2], a[:-1:step]
@@ -183,7 +199,7 @@ if all[1] == bord[0:]:
         self.assertEqual(ast.as_string(), code)
 
     def test_operator_precedence(self):
-        with open(resources.find('data/operator_precedence.py')) as f:
+        with open(resources.find("data/operator_precedence.py")) as f:
             for code in f:
                 self.check_as_string_ast_equality(code)
 
@@ -205,12 +221,13 @@ if all[1] == bord[0:]:
 
 class _NodeTest(unittest.TestCase):
     """test transformation of If Node"""
+
     CODE = None
 
     @property
     def astroid(self):
         try:
-            return self.__class__.__dict__['CODE_Astroid']
+            return self.__class__.__dict__["CODE_Astroid"]
         except KeyError:
             module = builder.parse(self.CODE)
             self.__class__.CODE_Astroid = module
@@ -219,6 +236,7 @@ class _NodeTest(unittest.TestCase):
 
 class IfNodeTest(_NodeTest):
     """test transformation of If Node"""
+
     CODE = """
         if 0:
             print()
@@ -332,7 +350,6 @@ class TryExcept2xNodeTest(_NodeTest):
             pass
     """
 
-
     def test_tuple_attribute(self):
         handler = self.astroid.body[0].handlers[0]
         self.assertIsInstance(handler.name, nodes.Tuple)
@@ -341,47 +358,49 @@ class TryExcept2xNodeTest(_NodeTest):
 class ImportNodeTest(resources.SysPathSetup, unittest.TestCase):
     def setUp(self):
         super(ImportNodeTest, self).setUp()
-        self.module = resources.build_file('data/module.py', 'data.module')
-        self.module2 = resources.build_file('data/module2.py', 'data.module2')
+        self.module = resources.build_file("data/module.py", "data.module")
+        self.module2 = resources.build_file("data/module2.py", "data.module2")
 
     def test_import_self_resolve(self):
-        myos = next(self.module2.igetattr('myos'))
+        myos = next(self.module2.igetattr("myos"))
         self.assertTrue(isinstance(myos, nodes.Module), myos)
-        self.assertEqual(myos.name, 'os')
-        self.assertEqual(myos.qname(), 'os')
-        self.assertEqual(myos.pytype(), '%s.module' % BUILTINS)
+        self.assertEqual(myos.name, "os")
+        self.assertEqual(myos.qname(), "os")
+        self.assertEqual(myos.pytype(), "%s.module" % BUILTINS)
 
     def test_from_self_resolve(self):
-        namenode = next(self.module.igetattr('NameNode'))
+        namenode = next(self.module.igetattr("NameNode"))
         self.assertTrue(isinstance(namenode, nodes.ClassDef), namenode)
-        self.assertEqual(namenode.root().name, 'astroid.node_classes')
-        self.assertEqual(namenode.qname(), 'astroid.node_classes.Name')
-        self.assertEqual(namenode.pytype(), '%s.type' % BUILTINS)
-        abspath = next(self.module2.igetattr('abspath'))
+        self.assertEqual(namenode.root().name, "astroid.node_classes")
+        self.assertEqual(namenode.qname(), "astroid.node_classes.Name")
+        self.assertEqual(namenode.pytype(), "%s.type" % BUILTINS)
+        abspath = next(self.module2.igetattr("abspath"))
         self.assertTrue(isinstance(abspath, nodes.FunctionDef), abspath)
-        self.assertEqual(abspath.root().name, 'os.path')
-        self.assertEqual(abspath.qname(), 'os.path.abspath')
-        self.assertEqual(abspath.pytype(), '%s.function' % BUILTINS)
+        self.assertEqual(abspath.root().name, "os.path")
+        self.assertEqual(abspath.qname(), "os.path.abspath")
+        self.assertEqual(abspath.pytype(), "%s.function" % BUILTINS)
 
     def test_real_name(self):
-        from_ = self.module['NameNode']
-        self.assertEqual(from_.real_name('NameNode'), 'Name')
-        imp_ = self.module['os']
-        self.assertEqual(imp_.real_name('os'), 'os')
-        self.assertRaises(exceptions.AttributeInferenceError, imp_.real_name, 'os.path')
-        imp_ = self.module['NameNode']
-        self.assertEqual(imp_.real_name('NameNode'), 'Name')
-        self.assertRaises(exceptions.AttributeInferenceError, imp_.real_name, 'Name')
-        imp_ = self.module2['YO']
-        self.assertEqual(imp_.real_name('YO'), 'YO')
-        self.assertRaises(exceptions.AttributeInferenceError, imp_.real_name, 'data')
+        from_ = self.module["NameNode"]
+        self.assertEqual(from_.real_name("NameNode"), "Name")
+        imp_ = self.module["os"]
+        self.assertEqual(imp_.real_name("os"), "os")
+        self.assertRaises(exceptions.AttributeInferenceError, imp_.real_name, "os.path")
+        imp_ = self.module["NameNode"]
+        self.assertEqual(imp_.real_name("NameNode"), "Name")
+        self.assertRaises(exceptions.AttributeInferenceError, imp_.real_name, "Name")
+        imp_ = self.module2["YO"]
+        self.assertEqual(imp_.real_name("YO"), "YO")
+        self.assertRaises(exceptions.AttributeInferenceError, imp_.real_name, "data")
 
     def test_as_string(self):
-        ast = self.module['modutils']
+        ast = self.module["modutils"]
         self.assertEqual(ast.as_string(), "from astroid import modutils")
-        ast = self.module['NameNode']
-        self.assertEqual(ast.as_string(), "from astroid.node_classes import Name as NameNode")
-        ast = self.module['os']
+        ast = self.module["NameNode"]
+        self.assertEqual(
+            ast.as_string(), "from astroid.node_classes import Name as NameNode"
+        )
+        ast = self.module["os"]
         self.assertEqual(ast.as_string(), "import os.path")
         code = """from . import here
 from .. import door
@@ -392,14 +411,14 @@ from ..cave import wine\n\n"""
 
     def test_bad_import_inference(self):
         # Explication of bug
-        '''When we import PickleError from nonexistent, a call to the infer
+        """When we import PickleError from nonexistent, a call to the infer
         method of this From node will be made by unpack_infer.
         inference.infer_from will try to import this module, which will fail and
         raise a InferenceException (by mixins.do_import_module). The infer_name
         will catch this exception and yield and Uninferable instead.
-        '''
+        """
 
-        code = '''
+        code = """
             try:
                 from pickle import PickleError
             except ImportError:
@@ -409,7 +428,7 @@ from ..cave import wine\n\n"""
                 pass
             except PickleError:
                 pass
-        '''
+        """
         module = builder.parse(code)
         handler_type = module.body[1].handlers[0].type
 
@@ -419,22 +438,22 @@ from ..cave import wine\n\n"""
         # be returned, from the _pickle module, which is not
         # present in the other version.
         self.assertIsInstance(excs[0], nodes.ClassDef)
-        self.assertEqual(excs[0].name, 'PickleError')
+        self.assertEqual(excs[0].name, "PickleError")
         self.assertIs(excs[-1], util.Uninferable)
 
     def test_absolute_import(self):
-        module = resources.build_file('data/absimport.py')
+        module = resources.build_file("data/absimport.py")
         ctx = contextmod.InferenceContext()
         # will fail if absolute import failed
-        ctx.lookupname = 'message'
-        next(module['message'].infer(ctx))
-        ctx.lookupname = 'email'
-        m = next(module['email'].infer(ctx))
-        self.assertFalse(m.file.startswith(os.path.join('data', 'email.py')))
+        ctx.lookupname = "message"
+        next(module["message"].infer(ctx))
+        ctx.lookupname = "email"
+        m = next(module["email"].infer(ctx))
+        self.assertFalse(m.file.startswith(os.path.join("data", "email.py")))
 
     def test_more_absolute_import(self):
-        module = resources.build_file('data/module1abs/__init__.py', 'data.module1abs')
-        self.assertIn('sys', module.locals)
+        module = resources.build_file("data/module1abs/__init__.py", "data.module1abs")
+        self.assertIn("sys", module.locals)
 
 
 class CmpNodeTest(unittest.TestCase):
@@ -444,7 +463,6 @@ class CmpNodeTest(unittest.TestCase):
 
 
 class ConstNodeTest(unittest.TestCase):
-
     def _test(self, value):
         node = nodes.const_factory(value)
         # pylint: disable=no-member; Infers two potential values
@@ -470,10 +488,10 @@ class ConstNodeTest(unittest.TestCase):
         self._test(1.0j)
 
     def test_str(self):
-        self._test('a')
+        self._test("a")
 
     def test_unicode(self):
-        self._test('a')
+        self._test("a")
 
     def test_copy(self):
         """
@@ -497,7 +515,7 @@ class NameNodeTest(unittest.TestCase):
                 builder.parse(code)
         else:
             ast = builder.parse(code)
-            assign_true = ast['True']
+            assign_true = ast["True"]
             self.assertIsInstance(assign_true, nodes.AssignName)
             self.assertEqual(assign_true.name, "True")
             del_true = ast.body[2].targets[0]
@@ -506,11 +524,13 @@ class NameNodeTest(unittest.TestCase):
 
 
 class AnnAssignNodeTest(unittest.TestCase):
-    @test_utils.require_version(minver='3.6')
+    @test_utils.require_version(minver="3.6")
     def test_primitive(self):
-        code = textwrap.dedent("""
+        code = textwrap.dedent(
+            """
             test: int = 5
-        """)
+        """
+        )
         assign = builder.extract_node(code)
         self.assertIsInstance(assign, nodes.AnnAssign)
         self.assertEqual(assign.target.name, "test")
@@ -518,94 +538,107 @@ class AnnAssignNodeTest(unittest.TestCase):
         self.assertEqual(assign.value.value, 5)
         self.assertEqual(assign.simple, 1)
 
-    @test_utils.require_version(minver='3.6')
+    @test_utils.require_version(minver="3.6")
     def test_primitive_without_initial_value(self):
-        code = textwrap.dedent("""
+        code = textwrap.dedent(
+            """
             test: str
-        """)
+        """
+        )
         assign = builder.extract_node(code)
         self.assertIsInstance(assign, nodes.AnnAssign)
         self.assertEqual(assign.target.name, "test")
         self.assertEqual(assign.annotation.name, "str")
         self.assertEqual(assign.value, None)
 
-    @test_utils.require_version(minver='3.6')
+    @test_utils.require_version(minver="3.6")
     def test_complex(self):
-        code = textwrap.dedent("""
+        code = textwrap.dedent(
+            """
             test: Dict[List[str]] = {}
-        """)
+        """
+        )
         assign = builder.extract_node(code)
         self.assertIsInstance(assign, nodes.AnnAssign)
         self.assertEqual(assign.target.name, "test")
         self.assertIsInstance(assign.annotation, astroid.Subscript)
         self.assertIsInstance(assign.value, astroid.Dict)
 
-    @test_utils.require_version(minver='3.6')
+    @test_utils.require_version(minver="3.6")
     def test_as_string(self):
-        code = textwrap.dedent("""
+        code = textwrap.dedent(
+            """
             print()
             test: int = 5
             test2: str
-            test3: List[Dict[(str, str)]] = []
-        """)
+            test3: List[Dict[str, str]] = []
+        """
+        )
         ast = abuilder.string_build(code)
         self.assertEqual(ast.as_string().strip(), code.strip())
 
 
 class ArgumentsNodeTC(unittest.TestCase):
     def test_linenumbering(self):
-        ast = builder.parse('''
+        ast = builder.parse(
+            """
             def func(a,
                 b): pass
             x = lambda x: None
-        ''')
-        self.assertEqual(ast['func'].args.fromlineno, 2)
-        self.assertFalse(ast['func'].args.is_statement)
-        xlambda = next(ast['x'].infer())
+        """
+        )
+        self.assertEqual(ast["func"].args.fromlineno, 2)
+        self.assertFalse(ast["func"].args.is_statement)
+        xlambda = next(ast["x"].infer())
         self.assertEqual(xlambda.args.fromlineno, 4)
         self.assertEqual(xlambda.args.tolineno, 4)
         self.assertFalse(xlambda.args.is_statement)
         if sys.version_info < (3, 0):
-            self.assertEqual(ast['func'].args.tolineno, 3)
+            self.assertEqual(ast["func"].args.tolineno, 3)
         else:
-            self.skipTest('FIXME  http://bugs.python.org/issue10445 '
-                          '(no line number on function args)')
+            self.skipTest(
+                "FIXME  http://bugs.python.org/issue10445 "
+                "(no line number on function args)"
+            )
 
-    @test_utils.require_version(minver='3.0')
+    @test_utils.require_version(minver="3.0")
     def test_kwoargs(self):
-        ast = builder.parse('''
+        ast = builder.parse(
+            """
             def func(*, x):
                 pass
-        ''')
-        args = ast['func'].args
-        self.assertTrue(args.is_argument('x'))
+        """
+        )
+        args = ast["func"].args
+        self.assertTrue(args.is_argument("x"))
 
 
 class UnboundMethodNodeTest(unittest.TestCase):
-
     def test_no_super_getattr(self):
         # This is a test for issue
         # https://bitbucket.org/logilab/astroid/issue/91, which tests
         # that UnboundMethod doesn't call super when doing .getattr.
 
-        ast = builder.parse('''
+        ast = builder.parse(
+            """
         class A(object):
             def test(self):
                 pass
         meth = A.test
-        ''')
-        node = next(ast['meth'].infer())
+        """
+        )
+        node = next(ast["meth"].infer())
         with self.assertRaises(exceptions.AttributeInferenceError):
-            node.getattr('__missssing__')
-        name = node.getattr('__name__')[0]
+            node.getattr("__missssing__")
+        name = node.getattr("__name__")[0]
         self.assertIsInstance(name, nodes.Const)
-        self.assertEqual(name.value, 'test')
+        self.assertEqual(name.value, "test")
 
 
 class BoundMethodNodeTest(unittest.TestCase):
-
     def test_is_property(self):
-        ast = builder.parse('''
+        ast = builder.parse(
+            """
         import abc
 
         def cached_property():
@@ -647,19 +680,26 @@ class BoundMethodNodeTest(unittest.TestCase):
         lazy_prop = cls.lazy_prop
         lazyprop = cls.lazyprop
         decorated_with_lazy = cls.decorated_with_lazy
-        ''')
-        for prop in ('builtin_property', 'abc_property', 'cached_p', 'reified',
-                     'lazy_prop', 'lazyprop', 'decorated_with_lazy'):
+        """
+        )
+        for prop in (
+            "builtin_property",
+            "abc_property",
+            "cached_p",
+            "reified",
+            "lazy_prop",
+            "lazyprop",
+            "decorated_with_lazy",
+        ):
             inferred = next(ast[prop].infer())
             self.assertIsInstance(inferred, nodes.Const, prop)
             self.assertEqual(inferred.value, 42, prop)
 
-        inferred = next(ast['not_prop'].infer())
+        inferred = next(ast["not_prop"].infer())
         self.assertIsInstance(inferred, bases.BoundMethod)
 
 
 class AliasesTest(unittest.TestCase):
-
     def setUp(self):
         self.transformer = transforms.TransformVisitor()
 
@@ -669,45 +709,45 @@ class AliasesTest(unittest.TestCase):
 
     def test_aliases(self):
         def test_from(node):
-            node.names = node.names + [('absolute_import', None)]
+            node.names = node.names + [("absolute_import", None)]
             return node
 
         def test_class(node):
-            node.name = 'Bar'
+            node.name = "Bar"
             return node
 
         def test_function(node):
-            node.name = 'another_test'
+            node.name = "another_test"
             return node
 
         def test_callfunc(node):
-            if node.func.name == 'Foo':
-                node.func.name = 'Bar'
+            if node.func.name == "Foo":
+                node.func.name = "Bar"
                 return node
             return None
 
         def test_assname(node):
-            if node.name == 'foo':
-                return nodes.AssignName('bar', node.lineno, node.col_offset,
-                                        node.parent)
+            if node.name == "foo":
+                return nodes.AssignName(
+                    "bar", node.lineno, node.col_offset, node.parent
+                )
             return None
 
         def test_assattr(node):
-            if node.attrname == 'a':
-                node.attrname = 'b'
+            if node.attrname == "a":
+                node.attrname = "b"
                 return node
             return None
 
         def test_getattr(node):
-            if node.attrname == 'a':
-                node.attrname = 'b'
+            if node.attrname == "a":
+                node.attrname = "b"
                 return node
             return None
 
         def test_genexpr(node):
             if node.elt.value == 1:
-                node.elt = nodes.Const(2, node.lineno, node.col_offset,
-                                       node.parent)
+                node.elt = nodes.Const(2, node.lineno, node.col_offset, node.parent)
                 return node
             return None
 
@@ -720,7 +760,7 @@ class AliasesTest(unittest.TestCase):
         self.transformer.register_transform(nodes.Attribute, test_getattr)
         self.transformer.register_transform(nodes.GeneratorExp, test_genexpr)
 
-        string = '''
+        string = """
         from __future__ import print_function
 
         class Foo: pass
@@ -731,40 +771,41 @@ class AliasesTest(unittest.TestCase):
         foo.a = test(42)
         foo.a
         (1 for _ in range(0, 42))
-        '''
+        """
 
         module = self.parse_transform(string)
 
         self.assertEqual(len(module.body[0].names), 2)
         self.assertIsInstance(module.body[0], nodes.ImportFrom)
-        self.assertEqual(module.body[1].name, 'Bar')
+        self.assertEqual(module.body[1].name, "Bar")
         self.assertIsInstance(module.body[1], nodes.ClassDef)
-        self.assertEqual(module.body[2].name, 'another_test')
+        self.assertEqual(module.body[2].name, "another_test")
         self.assertIsInstance(module.body[2], nodes.FunctionDef)
-        self.assertEqual(module.body[3].targets[0].name, 'bar')
+        self.assertEqual(module.body[3].targets[0].name, "bar")
         self.assertIsInstance(module.body[3].targets[0], nodes.AssignName)
-        self.assertEqual(module.body[3].value.func.name, 'Bar')
+        self.assertEqual(module.body[3].value.func.name, "Bar")
         self.assertIsInstance(module.body[3].value, nodes.Call)
-        self.assertEqual(module.body[4].targets[0].attrname, 'b')
+        self.assertEqual(module.body[4].targets[0].attrname, "b")
         self.assertIsInstance(module.body[4].targets[0], nodes.AssignAttr)
         self.assertIsInstance(module.body[5], nodes.Expr)
-        self.assertEqual(module.body[5].value.attrname, 'b')
+        self.assertEqual(module.body[5].value.attrname, "b")
         self.assertIsInstance(module.body[5].value, nodes.Attribute)
         self.assertEqual(module.body[6].value.elt.value, 2)
         self.assertIsInstance(module.body[6].value, nodes.GeneratorExp)
 
 
-@test_utils.require_version('3.5')
+@test_utils.require_version("3.5")
 class Python35AsyncTest(unittest.TestCase):
-
     def test_async_await_keywords(self):
-        async_def, async_for, async_with, await_node = builder.extract_node('''
+        async_def, async_for, async_with, await_node = builder.extract_node(
+            """
         async def func(): #@
             async for i in range(10): #@
                 f = __(await i)
             async with test(): #@
                 pass
-        ''')
+        """
+        )
         self.assertIsInstance(async_def, nodes.AsyncFunctionDef)
         self.assertIsInstance(async_for, nodes.AsyncFor)
         self.assertIsInstance(async_with, nodes.AsyncWith)
@@ -776,96 +817,102 @@ class Python35AsyncTest(unittest.TestCase):
         self.assertEqual(ast_node.as_string().strip(), code.strip())
 
     def test_await_as_string(self):
-        code = textwrap.dedent('''
+        code = textwrap.dedent(
+            """
         async def function():
             await 42
             await x[0]
             (await x)[0]
             await (x + y)[0]
-        ''')
+        """
+        )
         self._test_await_async_as_string(code)
 
     def test_asyncwith_as_string(self):
-        code = textwrap.dedent('''
+        code = textwrap.dedent(
+            """
         async def function():
             async with 42:
                 pass
-        ''')
+        """
+        )
         self._test_await_async_as_string(code)
 
     def test_asyncfor_as_string(self):
-        code = textwrap.dedent('''
+        code = textwrap.dedent(
+            """
         async def function():
             async for i in range(10):
                 await 42
-        ''')
+        """
+        )
         self._test_await_async_as_string(code)
 
 
 class ContextTest(unittest.TestCase):
-
     def test_subscript_load(self):
-        node = builder.extract_node('f[1]')
+        node = builder.extract_node("f[1]")
         self.assertIs(node.ctx, astroid.Load)
 
     def test_subscript_del(self):
-        node = builder.extract_node('del f[1]')
+        node = builder.extract_node("del f[1]")
         self.assertIs(node.targets[0].ctx, astroid.Del)
 
     def test_subscript_store(self):
-        node = builder.extract_node('f[1] = 2')
+        node = builder.extract_node("f[1] = 2")
         subscript = node.targets[0]
         self.assertIs(subscript.ctx, astroid.Store)
 
     def test_list_load(self):
-        node = builder.extract_node('[]')
+        node = builder.extract_node("[]")
         self.assertIs(node.ctx, astroid.Load)
 
     def test_list_del(self):
-        node = builder.extract_node('del []')
+        node = builder.extract_node("del []")
         self.assertIs(node.targets[0].ctx, astroid.Del)
 
     def test_list_store(self):
         with self.assertRaises(exceptions.AstroidSyntaxError):
-            builder.extract_node('[0] = 2')
+            builder.extract_node("[0] = 2")
 
     def test_tuple_load(self):
-        node = builder.extract_node('(1, )')
+        node = builder.extract_node("(1, )")
         self.assertIs(node.ctx, astroid.Load)
 
     def test_tuple_store(self):
         with self.assertRaises(exceptions.AstroidSyntaxError):
-            builder.extract_node('(1, ) = 3')
+            builder.extract_node("(1, ) = 3")
 
-    @test_utils.require_version(minver='3.5')
+    @test_utils.require_version(minver="3.5")
     def test_starred_load(self):
-        node = builder.extract_node('a = *b')
+        node = builder.extract_node("a = *b")
         starred = node.value
         self.assertIs(starred.ctx, astroid.Load)
 
-    @test_utils.require_version(minver='3.0')
+    @test_utils.require_version(minver="3.0")
     def test_starred_store(self):
-        node = builder.extract_node('a, *b = 1, 2')
+        node = builder.extract_node("a, *b = 1, 2")
         starred = node.targets[0].elts[1]
         self.assertIs(starred.ctx, astroid.Store)
 
 
 def test_unknown():
     """Test Unknown node"""
-    assert isinstance(next(nodes.Unknown().infer()),
-                      type(util.Uninferable))
+    assert isinstance(next(nodes.Unknown().infer()), type(util.Uninferable))
     assert isinstance(nodes.Unknown().name, str)
     assert isinstance(nodes.Unknown().qname(), str)
 
 
 @pytest.mark.skipif(not HAS_TYPED_AST, reason="requires typed_ast")
 def test_type_comments_with():
-    module = builder.parse('''
+    module = builder.parse(
+        """
     with a as b: # type: int
         pass
     with a as b: # type: ignore
         pass
-    ''')
+    """
+    )
     node = module.body[0]
     ignored_node = module.body[1]
     assert isinstance(node.type_annotation, astroid.Name)
@@ -875,48 +922,55 @@ def test_type_comments_with():
 
 @pytest.mark.skipif(not HAS_TYPED_AST, reason="requires typed_ast")
 def test_type_comments_for():
-    module = builder.parse('''
+    module = builder.parse(
+        """
     for a, b in [1, 2, 3]: # type: List[int]
         pass
     for a, b in [1, 2, 3]: # type: ignore
         pass
-    ''')
+    """
+    )
     node = module.body[0]
     ignored_node = module.body[1]
     assert isinstance(node.type_annotation, astroid.Subscript)
-    assert node.type_annotation.as_string() == 'List[int]'
+    assert node.type_annotation.as_string() == "List[int]"
 
     assert ignored_node.type_annotation is None
 
 
 @pytest.mark.skipif(not HAS_TYPED_AST, reason="requires typed_ast")
 def test_type_coments_assign():
-    module = builder.parse('''
+    module = builder.parse(
+        """
     a, b = [1, 2, 3] # type: List[int]
     a, b = [1, 2, 3] # type: ignore
-    ''')
+    """
+    )
     node = module.body[0]
     ignored_node = module.body[1]
     assert isinstance(node.type_annotation, astroid.Subscript)
-    assert node.type_annotation.as_string() == 'List[int]'
+    assert node.type_annotation.as_string() == "List[int]"
 
     assert ignored_node.type_annotation is None
 
 
 @pytest.mark.skipif(not HAS_TYPED_AST, reason="requires typed_ast")
 def test_type_comments_invalid_expression():
-    module = builder.parse('''
+    module = builder.parse(
+        """
     a, b = [1, 2, 3] # type: something completely invalid
     a, b = [1, 2, 3] # typeee: 2*+4
     a, b = [1, 2, 3] # type: List[int
-    ''')
+    """
+    )
     for node in module.body:
         assert node.type_annotation is None
 
 
 @pytest.mark.skipif(not HAS_TYPED_AST, reason="requires typed_ast")
 def test_type_comments_invalid_function_comments():
-    module = builder.parse('''
+    module = builder.parse(
+        """
     def func():
         # type: something completely invalid
         pass
@@ -926,7 +980,8 @@ def test_type_comments_invalid_function_comments():
     def func2():
         # type: List[int
         pass
-    ''')
+    """
+    )
     for node in module.body:
         assert node.type_comment_returns is None
         assert node.type_comment_args is None
@@ -934,7 +989,8 @@ def test_type_comments_invalid_function_comments():
 
 @pytest.mark.skipif(not HAS_TYPED_AST, reason="requires typed_ast")
 def test_type_comments_function():
-    module = builder.parse('''
+    module = builder.parse(
+        """
     def func():
         # type: (int) -> str
         pass
@@ -944,17 +1000,16 @@ def test_type_comments_function():
     def func2():
         # type: (int, int, str, List[int]) -> List[int]
         pass
-    ''')
+    """
+    )
     expected_annotations = [
         (["int"], astroid.Name, "str"),
         (["int", "int", "int"], astroid.Tuple, "(str, str)"),
         (["int", "int", "str", "List[int]"], astroid.Subscript, "List[int]"),
     ]
-    for node, (
-            expected_args,
-            expected_returns_type,
-            expected_returns_string
-        ) in zip(module.body, expected_annotations):
+    for node, (expected_args, expected_returns_type, expected_returns_string) in zip(
+        module.body, expected_annotations
+    ):
         assert node.type_comment_returns is not None
         assert node.type_comment_args is not None
         for expected_arg, actual_arg in zip(expected_args, node.type_comment_args):
@@ -964,7 +1019,8 @@ def test_type_comments_function():
 
 
 def test_is_generator_for_yield_assignments():
-    node = astroid.extract_node('''
+    node = astroid.extract_node(
+        """
     class A:
         def test(self):
             a = yield
@@ -973,11 +1029,66 @@ def test_is_generator_for_yield_assignments():
                 yield a
     a = A()
     a.test
-    ''')
+    """
+    )
     inferred = next(node.infer())
     assert isinstance(inferred, astroid.BoundMethod)
     assert bool(inferred.is_generator())
 
 
-if __name__ == '__main__':
+class AsyncGeneratorTest:
+    @test_utils.require_version(minver="3.6")
+    def test_async_generator(self):
+        node = astroid.extract_node(
+            """
+        async def a_iter(n):
+            for i in range(1, n + 1):
+                yield i
+                await asyncio.sleep(1)
+        a_iter(2) #@
+        """
+        )
+        inferred = next(node.infer())
+        assert isinstance(inferred, bases.AsyncGenerator)
+        assert inferred.getattr("__aiter__")
+        assert inferred.getattr("__anext__")
+        assert inferred.pytype() == "builtins.async_generator"
+        assert inferred.display_type() == "AsyncGenerator"
+
+    @test_utils.require_version(maxver="3.5")
+    def test_async_generator_is_generator_on_older_python(self):
+        node = astroid.extract_node(
+            """
+        async def a_iter(n):
+            for i in range(1, n + 1):
+                yield i
+                await asyncio.sleep(1)
+        a_iter(2) #@
+        """
+        )
+        inferred = next(node.infer())
+        assert isinstance(inferred, bases.Generator)
+        assert inferred.getattr("__iter__")
+        assert inferred.getattr("__next__")
+        assert inferred.pytype() == "builtins.generator"
+        assert inferred.display_type() == "Generator"
+
+
+@pytest.mark.skipif(sys.version_info[:2] < (3, 6), reason="needs f-string support")
+def test_f_string_correct_line_numbering():
+    """Test that we generate correct line numbers for f-strings"""
+    node = astroid.extract_node(
+        """
+    def func_foo(arg_bar, arg_foo):
+        dict_foo = {}
+
+        f'{arg_bar.attr_bar}' #@
+    """
+    )
+    assert node.lineno == 5
+    assert node.last_child().lineno == 5
+    assert node.last_child().last_child().lineno == 5
+
+
+if __name__ == "__main__":
     unittest.main()
